# Intentional - Telegram

[![PyPI - Version](https://img.shields.io/pypi/v/intentional-telegram.svg)](https://pypi.org/project/intentional-telegram)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/intentional-telegram.svg)](https://pypi.org/project/intentional-telegram)
[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-orange.json)](https://github.com/copier-org/copier)

Plugin that uses Telegram as the interface to communicate with your Intentional bot

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install intentional-telegram
```

## License

`intentional` is distributed under the terms of the [AGPL](LICENSE.txt) license.
